/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using System;
using System.Collections.Generic;

[AttributeUsage(AttributeTargets.Assembly, AllowMultiple = true)]
public class DefaultConfigAttribute : Attribute {
    public DefaultConfigAttribute() : this(string.Empty) {}
    public DefaultConfigAttribute(string txt)
    {
        int eq_pos = txt.IndexOf('=');
        if (eq_pos == -1)
            throw new FormatException("Config must be written like \"Key1=Value1\"");

        Key = txt.Substring(0, eq_pos).Trim();
        Value = txt.Substring(eq_pos+1).Trim();
    }

    public string Key { get; private set; }
    public string Value { get; private set; }
}
